Coverage report

# Coverage report: 26%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 117 | 87 | 0 | 26%
conftest.py | 58 | 34 | 0 | 41%
test_asg.py | 6 | 0 | 0 | 100%
test_cli.py | 5 | 5 | 0 | 0%
test_ec2.py | 38 | 38 | 0 | 0%
test_elb.py | 8 | 8 | 0 | 0%
test_emr.py | 2 | 2 | 0 | 0%

No items found using the specified filter.